@@ -30,11 +30,12 @@ import argparse
 import fs
 from fs.opener import parse
 from PyQt5 import QtWidgets, QtCore
-from PyQt5.QtWidgets import QAbstractItemView, QInputDialog, QErrorMessage
+from PyQt5.QtWidgets import QAbstractItemView, QInputDialog, QErrorMessage, QMessageBox
 from PyQt5.QtGui import QIcon
+from PyQt5.QtCore import QSettings
 from fslib import ui_filepicker, __version__
 from fslib.utils import root_url, human_readable_info, match_extension,\
-    FOLDER_SPACES, FILES_SPACES, WidgetImage, get_extension_from_string
+    FOLDER_SPACES, FILES_SPACES, WidgetImage, get_extension_from_string, fs_url_exists
 from fslib.icons import icons
 
 
@@ -43,6 +44,7 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
                  default_filename=None, show_save_action=False, show_dirs_only=False):
         super(FilePicker, self).__init__(parent)
         self.setupUi(self)
+        self.settings = QSettings("fs_filepicker")
         self.setWindowIcon(QIcon(icons('fs_logo.png', origin='fs')))
         self.file_icon = icons('text-x-generic.png')
         self.dir_icon = icons('folder.png')
@@ -51,7 +53,24 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         self.filename = None
         self.wparm = None
         self.setWindowTitle(title)
-        self.fs_url = fs_url
+        stored_fs_url = self.settings.value("fs_urls", fs_url)
+        if isinstance(fs_url, list):
+            self.fs_url = fs_url[0]
+            if isinstance(stored_fs_url, list):
+                for _fs_url in stored_fs_url:
+                    if fs_url_exists(_fs_url):
+                        self.ui_fs_serverlist.addItem(_fs_url)
+                for _fs_url in fs_url:
+                    if fs_url_exists(_fs_url):
+                        self.ui_fs_serverlist.addItem(_fs_url)
+        else:
+            if isinstance(stored_fs_url, list):
+                for _fs_url in stored_fs_url:
+                    if fs_url_exists(_fs_url):
+                        self.ui_fs_serverlist.addItem(_fs_url)
+            else:
+                self.ui_fs_serverlist.hide()
+            self.fs_url = fs_url
         self.fs_home_url = u"~/"
         self.fs_root_url = root_url()
         self.active_url = self.fs_url
@@ -87,8 +106,9 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         self.ui_FileList.cellDoubleClicked.connect(self.onCellDoubleClicked)
         self.ui_FileList.setSelectionBehavior(QAbstractItemView.SelectRows)
         self.ui_DirList.currentIndexChanged.connect(self.selection_directory)
-        self.ui_fs_serverlist.hide()
+
         self.ui_fs_serverlist.clicked.connect(self.fs_select_other)
+        self.ui_fs_serverlist.customContextMenuRequested.connect(self.fs_select_other_context)
         # ToDo check order of calls
         self.active_url = self.fs_url
         self.select_fs()
@@ -160,23 +180,35 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
 
     def other_fs_button(self):
         fs_url, ok = QInputDialog.getText(self, 'Other FS Urls', 'Enter FS Url:')
-        _fs = None
         if ok:
-            try:
-                _fs = fs.open_fs(fs_url)
-            except fs.errors.CreateFailed:
+            if fs_url_exists(fs_url):
+                self.ui_fs_serverlist.setVisible(True)
+                self.ui_fs_serverlist.addItem(fs_url)
+                self.save_fs_urls_settings()
+            else:
                 msg = u'"%s" Url not valid' % fs_url
                 QErrorMessage(self).showMessage(msg)
                 logging.info(msg)
-            if _fs is not None:
-                self.ui_fs_serverlist.setVisible(True)
-                self.ui_fs_serverlist.addItem(fs_url)
 
     def fs_select_other(self):
         url = self.ui_fs_serverlist.currentItem().text()
         self.active_url = url
         self.select_fs()
 
+    def fs_select_other_context(self):
+        """
+        simple context option, removes item from list
+        """
+        url = self.ui_fs_serverlist.currentItem().text()
+        msg = QtWidgets.QMessageBox()
+        selected = msg.information(self, u"Remove FS Dir", url, QMessageBox.Ok | QMessageBox.Cancel)
+        if selected == QMessageBox.Ok:
+            self.ui_fs_serverlist.clear()
+            for item in self.settings.value("fs_urls"):
+                if item != url:
+                    self.ui_fs_serverlist.addItem(item)
+            self.save_fs_urls_settings()
+
     def select_fs(self):
         """
         loads the selected fs to the file list ui
@@ -503,6 +535,13 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
             else:
                 self.close()
 
+    def save_fs_urls_settings(self):
+        items = []
+        for index in xrange(self.ui_fs_serverlist.count()):
+            items.append(self.ui_fs_serverlist.item(index).text())
+        self.settings.setValue('fs_urls', items)
+        self.settings.sync()
+
 
 def fs_filepicker(parent=None, fs_url=u'~/', file_pattern=u'All Files (*)', title=u'FS File Picker',
                   default_filename=None, show_save_action=False, show_dirs_only=False):
